summaryrefslogtreecommitdiffstats
path: root/modules/fdlibm/patches/12_define_u_int32_t_and_u_int64_t_on_windows.patch
diff options
context:
space:
mode:
Diffstat (limited to 'modules/fdlibm/patches/12_define_u_int32_t_and_u_int64_t_on_windows.patch')
-rw-r--r--modules/fdlibm/patches/12_define_u_int32_t_and_u_int64_t_on_windows.patch10
1 files changed, 5 insertions, 5 deletions
diff --git a/modules/fdlibm/patches/12_define_u_int32_t_and_u_int64_t_on_windows.patch b/modules/fdlibm/patches/12_define_u_int32_t_and_u_int64_t_on_windows.patch
index c0e9814aa..106d64dbc 100644
--- a/modules/fdlibm/patches/12_define_u_int32_t_and_u_int64_t_on_windows.patch
+++ b/modules/fdlibm/patches/12_define_u_int32_t_and_u_int64_t_on_windows.patch
@@ -1,7 +1,7 @@
diff --git a/modules/fdlibm/src/math_private.h b/modules/fdlibm/src/math_private.h
--- a/modules/fdlibm/src/math_private.h
+++ b/modules/fdlibm/src/math_private.h
-@@ -33,16 +33,21 @@
+@@ -33,16 +33,23 @@
* to dig two 32 bit words out of the 64 bit IEEE floating point
* value. That is non-ANSI, and, moreover, the gcc instruction
* scheduler gets it wrong. We instead use the following macros.
@@ -17,11 +17,11 @@ diff --git a/modules/fdlibm/src/math_private.h b/modules/fdlibm/src/math_private
+#define u_int64_t uint64_t
+#endif
+
- /*
- * A union which permits us to convert between a double and two 32 bit
- * ints.
- */
+ /* A union which permits us to convert between a long double and
+ four 32 bit ints. */
#if MOZ_BIG_ENDIAN
typedef union
+ {
+ long double value;